export declare const COMMAND: {
    START_LISTENING: string;
    STOP_LISTENING: string;
    HAS_TEXT: string;
    HAS_RTF: string;
    HAS_HTML: string;
    HAS_IMAGE: string;
    HAS_FILES: string;
    READ_TEXT: string;
    READ_RTF: string;
    READ_HTML: string;
    READ_IMAGE: string;
    READ_FILES: string;
    WRITE_TEXT: string;
    WRITE_RTF: string;
    WRITE_HTML: string;
    WRITE_IMAGE: string;
    WRITE_FILES: string;
    CLEAR: string;
    GET_DEFAULT_SAVE_IMAGE_PATH: string;
    CLIPBOARD_CHANGED: string;
};
export interface ReadImage {
    path: string;
    size: number;
    width: number;
    height: number;
}
export interface ReadFile {
    paths: string[];
    size: number;
}
export type ClipboardContentType = "text" | "rtf" | "html" | "image" | "files";
export type ReadClipboardItem<T extends ClipboardContentType = ClipboardContentType> = {
    type: T;
    value: T extends "files" ? string[] : string;
    count: number;
} & (T extends "image" ? {
    width: number;
    height: number;
} : {});
export type ReadClipboardItemUnion<T extends ClipboardContentType = ClipboardContentType> = {
    [K in T]: ReadClipboardItem<K>;
}[T];
export type ReadClipboard = Partial<{
    [K in ClipboardContentType]: ReadClipboardItem<K>;
}>;
export type ClipboardChangeCallback = (result: ReadClipboard) => void;
export interface ClipboardChangeOptions {
    beforeRead?: () => void;
}
/**
 * Start listening for clipboard changes.
 *
 * @example
 * ```
 * import { startListening } from 'tauri-plugin-clipboard-x-api';
 *
 * await startListening();
 * ```
 */
export declare const startListening: () => Promise<unknown>;
/**
 * Stop listening for clipboard changes.
 *
 * @example
 * ```
 * import { stopListening } from 'tauri-plugin-clipboard-x-api';
 *
 * await stopListening();
 * ```
 */
export declare const stopListening: () => Promise<unknown>;
/**
 * Check if the clipboard contains plain text.
 *
 * @example
 * ```
 * import { hasText } from 'tauri-plugin-clipboard-x-api';
 *
 * const has = await hasText();
 * console.log(has); // true
 * ```
 */
export declare const hasText: () => Promise<boolean>;
/**
 * Check if the clipboard contains rich text.
 *
 * @example
 * ```
 * import { hasRTF } from 'tauri-plugin-clipboard-x-api';
 *
 * const has = await hasRTF();
 * console.log(has); // true
 * ```
 */
export declare const hasRTF: () => Promise<boolean>;
/**
 * Check if the clipboard contains html.
 *
 * @example
 * ```
 * import { hasHTML } from 'tauri-plugin-clipboard-x-api';
 *
 * const has = await hasHTML();
 * console.log(has); // true
 * ```
 */
export declare const hasHTML: () => Promise<boolean>;
/**
 * Check if the clipboard contains an image.
 *
 * @example
 * ```
 * import { hasImage } from 'tauri-plugin-clipboard-x-api';
 *
 * const has = await hasImage();
 * console.log(has); // true
 * ```
 */
export declare const hasImage: () => Promise<boolean>;
/**
 * Check if the clipboard contains files.
 *
 * @example
 * ```
 * import { hasFiles } from 'tauri-plugin-clipboard-x-api';
 *
 * const has = await hasFiles();
 * console.log(has); // true
 * ```
 */
export declare const hasFiles: () => Promise<boolean>;
/**
 * Read the clipboard as plain text.
 *
 * @example
 * ```
 * import { readText } from 'tauri-plugin-clipboard-x-api';
 *
 * const text = await readText();
 * console.log(text); // "Hello, world!"
 * ```
 */
export declare const readText: () => Promise<string>;
/**
 * Read the clipboard as rich text.
 *
 * @example
 * ```
 * import { readRTF } from 'tauri-plugin-clipboard-x-api';
 *
 * const rtf = await readRTF();
 * console.log(rtf); // "{\\rtf1 Hello, world!}"
 * ```
 */
export declare const readRTF: () => Promise<string>;
/**
 * Read the clipboard as html.
 *
 * @example
 * ```
 * import { readHTML } from 'tauri-plugin-clipboard-x-api';
 *
 * const html = await readHTML();
 * console.log(html); // "<h1>Hello, world!</h1>"
 * ```
 */
export declare const readHTML: () => Promise<string>;
/**
 * Read the clipboard as an image.
 *
 * @example
 * ```
 * import { readImage } from 'tauri-plugin-clipboard-x-api';
 *
 * const image = await readImage();
 * console.log(image); // { path: "/path/to/xxx.png", size: 1024, width: 100, height: 100 }
 * ```
 */
export declare const readImage: () => Promise<ReadImage>;
/**
 * Read the clipboard as files.
 *
 * @example
 * ```
 * import { readFiles } from 'tauri-plugin-clipboard-x-api';
 *
 * const files = await readFiles();
 * console.log(files); // { paths: ["/path/to/xxx.txt", "/path/to/xxx"], size: 1024 }
 * ```
 */
export declare const readFiles: () => Promise<ReadFile>;
/**
 * Write plain text to the clipboard.
 *
 * @example
 * ```
 * import { writeText } from 'tauri-plugin-clipboard-x-api';
 *
 * await writeText("Hello, world!");
 * ```
 */
export declare const writeText: (text: string) => Promise<unknown>;
/**
 * Write rich text to the clipboard.
 *
 * @param text The plain text.
 * @param rtf The rich text.
 *
 * @example
 * ```
 * import { writeRTF } from 'tauri-plugin-clipboard-x-api';
 *
 * await writeRTF("Hello, world!", "{\\rtf1 Hello, world!}");
 * ```
 */
export declare const writeRTF: (text: string, rtf: string) => Promise<unknown>;
/**
 * Write html to the clipboard.
 *
 * @param text The plain text.
 * @param html The html.
 *
 * @example
 * ```
 * import { writeHTML } from 'tauri-plugin-clipboard-x-api';
 *
 * await writeHTML("Hello, world!", "<h1>Hello, world!</h1>");
 * ```
 */
export declare const writeHTML: (text: string, html: string) => Promise<unknown>;
/**
 * Write an image to the clipboard.
 *
 * @example
 * ```
 * import { writeImage } from 'tauri-plugin-clipboard-x-api';
 *
 * await writeImage("/path/to/xxx.png");
 * ```
 */
export declare const writeImage: (image: string) => Promise<unknown>;
/**
 * Write files to the clipboard.
 *
 * @example
 * ```
 * import { writeFiles } from 'tauri-plugin-clipboard-x-api';
 *
 * await writeFiles(["/path/to/xxx.txt", "/path/to/xxx"]);
 * ```
 */
export declare const writeFiles: (files: string[]) => Promise<unknown>;
/**
 * Clear the clipboard.
 *
 * @example
 * ```
 * import { clear } from 'tauri-plugin-clipboard-x-api';
 *
 * await clear();
 * ```
 */
export declare const clear: () => Promise<unknown>;
/**
 * Get the default save image path.
 *
 * @example
 * ```
 * import { getDefaultSaveImagePath } from 'tauri-plugin-clipboard-x-api';
 *
 * const path = await getDefaultSaveImagePath();
 * console.log(path); // "xx/tauri-plugin-clipboard-x/images"
 * ```
 */
export declare const getDefaultSaveImagePath: () => Promise<string>;
/**
 * Read all available content from the clipboard.
 *
 * @example
 * ```
 * import { readClipboard } from 'tauri-plugin-clipboard-x-api';
 *
 * const result = await readClipboard();
 * ```
 *
@returns Promise<{@link ReadClipboard}>
 */
export declare const readClipboard: () => Promise<Partial<{
    text: {
        type: "text";
        value: string;
        count: number;
    };
    rtf: {
        type: "rtf";
        value: string;
        count: number;
    };
    html: {
        type: "html";
        value: string;
        count: number;
    };
    image: ReadClipboardItem<"image">;
    files: {
        type: "files";
        value: string[];
        count: number;
    };
}>>;
/**
 * Listen to clipboard changes.
 *
 * @param cb The callback function that will be called when clipboard changes.
 * @param options.beforeRead A hook that will be called before reading clipboard content.
 *
 * @example
 * ```
 * import { startListening, onClipboardChange } from 'tauri-plugin-clipboard-x-api';
 *
 * await startListening();
 *
 * const unlisten = await onClipboardChange((result) => {
 *   console.log(result);
 * });
 * ```
 */
export declare const onClipboardChange: (cb: ClipboardChangeCallback, options?: ClipboardChangeOptions) => Promise<import("@tauri-apps/api/event").UnlistenFn>;
